@@ -2,30 +2,65 @@ package App::Framework;
 
 =head1 NAME
 
-App::Framework::Base - Base application object
+App::Framework - A framework for creating applications
 
 =head1 SYNOPSIS
 
   use App::Framework ;
-
-or 
-
   use App::Framework qw/Script/ ;
 
   App::Framework->new()->go() ;
   
+  sub run
+  {
+	my ($app) = @_ ;
+	
+	# options
+	my %opts = $app->options() ;
+
+	# aplication code here....  	
+  }
 
 =head1 DESCRIPTION
 
-Base class for applications. Expected to be derived from by an implementable class (like App:Script).
+This class actually uses one of the framework sub-modules to provide it's "personality". By default that
+will be Script, but others will be available later (or if anyone adds their own). The personality is loaded
+into the framework at import time as part of the 'use':
 
-Base provides (and handles) the following options:
+  use App::Framework qw/Script/ ;
+
+(As stated above, if no personality is specified then 'Script' will be assumed).
+
+The framework is intended to do most of the common tasks required to set up an application, being driven 
+predominantly by the applications "documentation" (see section L</DATA>).
+
+=head2 COMMAND LINE OPTIONS
+
+The basic framework provides (and handles) the following pre-defined options:
 
 	debug			Set the debug level value
 	h|"help"		Show brief help message then exit
 	man				Show full man page then exit
 	pod				Show full man page as pod then exit
 
+Application-specific options are specified in the __DATA__ section under the heading [OPTIONS]. An example of which is:
+
+	[OPTIONS]
+	
+	-d|'dir'=s	temp directory	[default=/tmp]
+	
+	Specify the directory in which to store the xml output files (created by dumping the rrd databases)
+	
+	-repair 	Enable rrd repair
+	
+	When this option is specified, causes the script to repair any faulty rrd files
+
+Here two options -d (or -dir) and -repair are defined. In this case -d is used to specify a directory name and a default
+has been declared so that, if the user does not specify the option, the default value will be used. In the application itself,
+all options are accessed via the options HASH (accessed using $app->options())
+
+=head2 APPLICATION FUNCTIONS
+
 Once the object has been created it can then be run by calling the 'go()' method. go() calls in turn:
 
 	* pre_run()		Gets & processes the options, then calls the pre_run_fn if set
@@ -37,7 +72,9 @@ The pre_run_fn, run_fn, and post_run_fn fields of the object can either be set d
 or the prefered approach is to define pre_run, run, and post_run subroutines in the calling namespace. These subroutines
 are detected by App::Framework::Base and automatically set on the object.
 
-Similarly, the __DATA__ area of the calling namespace if the prefered area to use for object set up of common
+=head2 DATA
+
+Similarly, the __DATA__ area of the calling namespace is the prefered area to use for object set up of common
 fields (rather than as part of the new() call). Example __DATA__ contents:
 
 	__DATA__
@@ -74,15 +111,17 @@ fields (rather than as part of the new() call). Example __DATA__ contents:
 	
 	An export RRD database in XML file is of the form:
 	
-	  <!-- Round Robin Database Dump --><rrd>	<version> 0003 </version>
-		<step> 300 </step> <!-- Seconds -->
-		<lastupdate> 1211355308 </lastupdate> <!-- 2008-05-21 08:35:08 BST -->
  
 This example sets the fields: history, summary, synopsis, options, and description. This information is also used to 
 automatically create the application pod, man, and usage pages.
 
 Similarly, the $VERSION variable in the calling namespace is detected and used to set the application version number.
 
+In addition to specifying teh application settings, additional named __DATA__ sections can be created. These named sections are then accessed
+via $app->data($name) to recover the text string (or an array of the text lines). Named data sections are specified as:
+
+    __DATA__ name
+
 =head2 FIELDS
 
 The following fields should be defined either in the call to 'new()' or as part of the application configuration in the __DATA__ section:
@@ -114,23 +153,16 @@ During program execution, the following values can be accessed:
  * runobj = L<App::Framework::Base::Run> object
  
 
+=head2 Configuration
+
+App::Framework loads some settings from L<App::Framework::Config>. This may be modified on a site basis as required 
+(in a similar fashion to CPAN Config.pm). 
+
 
 =head2 Loaded modules
 
-App::Framework::Base pre-loads the user namespace with the following modules: 
+App::Framework pre-loads the user namespace with some common modules. See L<App::Framework::Config> for the complete list. 
 
-	'Cwd', 
-	'File::Basename',
-	'File::Path',
-	'File::Temp',
-	'File::Spec',
-	'File::Find',
-	'File::Copy',
-	"File::DosGlob 'glob'",
-	
-	'Pod::Usage',
-	'Date::Manip',
-	'Getopt::Long qw(:config no_ignore_case)',
 	
 =head2 MySql support
 
@@ -141,17 +173,27 @@ Calling to the sql() method with no parameter will return the first created L<Ap
 return the L<App::Framework::Base::Sql> object created for the named database (i.e. sql objects are named by their database). The sql object can then be
 used as defined in L<App::Framework::Base::Sql>
 
-=head2 HISTORY
+=head2 Further details
 
-I started this package ....
+The actual functionality (and hence most of the methods) of the class is provided by L<App::Framework::Base> which should be referred to
+for complete documentation.
 
+The personalities are described in:
+
+=over 4
+
+=item * Script
+
+L<App::Framework::Modules::Script>
+
+=back
 
 =cut
 
 use strict ;
 use Carp ;
 
-our $VERSION = "0.01" ;
+our $VERSION = "0.02" ;
 
 
 #============================================================================================
